@@ -128,4 +128,4 @@ class ColorfulMeta(type):
             return ColorfulParser.parse_attr(attr) % text
         return _decoratedText
 
-Colorful = ColorfulMeta("Colorful", (object, ), {})  # use metaclass ColorfulMeta for Colorful class
+colorful = ColorfulMeta("colorful", (object, ), {})  # use metaclass ColorfulMeta for Colorful class
